summaryrefslogtreecommitdiff
path: root/modules/libjar/nsZipArchive.h
diff options
context:
space:
mode:
Diffstat (limited to 'modules/libjar/nsZipArchive.h')
-rw-r--r--modules/libjar/nsZipArchive.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/modules/libjar/nsZipArchive.h b/modules/libjar/nsZipArchive.h
index 6b758c9fd8..133a2aa120 100644
--- a/modules/libjar/nsZipArchive.h
+++ b/modules/libjar/nsZipArchive.h
@@ -159,10 +159,10 @@ public:
*
* @param zipEntry Name of file in archive to extract
* @param outFD Filedescriptor to write contents to
* @param outname Name of file to write to
* @return status code
*/
- nsresult ExtractFile(nsZipItem * zipEntry, const char *outname, PRFileDesc * outFD);
+ nsresult ExtractFile(nsZipItem * zipEntry, nsIFile* outFile, PRFileDesc * outFD);
/**
* FindInit
@@ -159,10 +159,10 @@ public:
* @param zipEntry Name of file in archive to extract
* @param outFD Filedescriptor to write contents to
- * @param outname Name of file to write to
+ * @param outFile Handle of file to write to
* @return status code
*/